'use strict';

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var fs = require('fs');
var path = require('path');
var Engine = require('./engine');

/**
 * Default options
 */
var defaultOptions = {
    cached: false,
    files: []
};

/**
 * Find project path
 * @param {String} cwd
 * @return {String} 
 */
function findProjectRoot(cwd) {
    var list = cwd.split(path.sep);
    var root = void 0;
    for (var i = 0; i < list.length; i++) {
        var dir = list.slice(0, list.length - i).join(path.sep);
        if (fs.existsSync(path.join(dir, '.git')) || fs.existsSync(path.join(dir, '.svn')) || fs.existsSync(path.join(dir, '.cilintrc.js'))) {
            root = dir;
            break;
        }
    }

    return root;
}

var CliEngine = function () {
    /**
     * @construtor
     * @param {Object} options 
     * @param {?Array.<String>} options.files lint files
     * @param {Boolean} options.cached 
     */
    function CliEngine(options) {
        _classCallCheck(this, CliEngine);

        options = Object.assign({}, defaultOptions, options);

        this.cwd = process.cwd();

        var root = this.root = findProjectRoot(this.cwd);

        if (!root) {
            throw new Error('No .cilintrc.js/.git/.svn found');
        }

        // read cilintrc
        var rcPath = path.join(root, '.cilintrc.js');

        if (!fs.existsSync(rcPath)) {
            throw new Error('No .cilintrc.js found on dir ', root);
        }

        try {
            // set rc
            this.rc = require(rcPath);
        } catch (ex) {
            throw new Error('.cilintrc.js parse error', ex.toString());
        }

        this.options = options;
    }

    /**
     * Get lint results
     * @return {Array.<Object>} 
     */


    _createClass(CliEngine, [{
        key: 'getResults',
        value: function getResults() {
            var engine = new Engine(Object.assign({}, this.options, {
                rc: this.rc,
                cwd: this.cwd,
                root: this.root
            }));

            return engine.getResults();
        }
    }]);

    return CliEngine;
}();

module.exports = CliEngine;